#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unicode-show
version:              0.1.1.1
visibility:           public
id:                   unicode-show-0.1.1.1-ARtKBI77fDf4u0Crx4wZoZ
key:                  unicode-show-0.1.1.1-ARtKBI77fDf4u0Crx4wZoZ
license:              BSD-3-Clause
copyright:            2016 Takayuki Muranushi
maintainer:           igrep@n.email.ne.jp
author:               Takayuki Muranushi
homepage:             http://github.com/haskell-jp/unicode-show#readme
synopsis:             print and show in unicode
description:
    This package provides variants of '\''show'\'' and '\''print'\'' functions that does not escape non-ascii characters.

    See <http://github.com/haskell-jp/unicode-show#readme README> for usage.

    Run ghci with  @-interactive-print@ flag to print unicode characters. See <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/interactive-evaluation.html#ghci-interactive-print Using a custom interactive printing function> section in the GHC manual.

category:             Text
abi:                  699904fbd28d7096daf5e6a2a031fed9
exposed:              True
exposed-modules:      Text.Show.Unicode
import-dirs:          /usr/lib/ghc-9.6.6/site-local/unicode-show-0.1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/unicode-show-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/unicode-show-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unicode-show
hs-libraries:         HSunicode-show-0.1.1.1-ARtKBI77fDf4u0Crx4wZoZ
depends:
    base-4.18.2.1 safe-0.3.21-FUSW86GEeen8gJ9UgiYnyw
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-unicode-show/html/unicode-show.haddock

haddock-html:         /usr/share/doc/haskell-unicode-show/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

